
.aloha-align-left {
	text-align: left;
}

.aloha-align-right {
	text-align: right;
}

.aloha-align-center {
	text-align: center;
}

.aloha-align-justifiy {
	text-align: justify;
}

img.aloha-align-left {
	float: left;
}

img.aloha-align-right {
	float: right;
}

img.djaloha-current-image {
	border: solid red 1px;
}