{% extends "coop_cms/base.html" %}
{% load i18n static article_tags %}

{% block meta_title %}
    {{ category.name }}
{% endblock %}


{% block document %}

    {% block title %}
        <h2 id="title">{{ category.name }}</h2>
    {% endblock %}

    <ul>
        {% last_articles 10 "coop_cms/article_list_item.html" category %}
    </ul>

{% endblock %}
